==> flutter_query-0.0.7.tar.gz: test/use_query_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:flutter_query/flutter_query.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  testWidgets('useQuery', (tester) async {
    var passed = false;

    await tester.pumpFrames(
      QueryCacheProvider(
        child: HookBuilder(
          builder: (context) {
            final snapshot = useQuery(
              'data',
              () => Future.value('Hello world!'),
            );
            if (snapshot.hasData) {
              passed = true;
            }
            return HookBuilder(builder: (context) {
              useQuery('data', ([args]) => Future.value('Hello world!'));
              return Container();
            });
          },
        ),
      ),
      Duration(seconds: 5),
    );

    expect(passed, true);
  });

  testWidgets('useInfiniteQuery', (tester) async {
    var passed = false;
    var index = 0;

    await tester.pumpFrames(
      QueryCacheProvider(
        child: HookBuilder(
          builder: (context) {
            final context = useInfiniteQuery<List>(
              'data',
              (page) {
                print(page.toString());
                return Future.value(page > 0 ? [] : ['Test', 'Test', 'Test']);
              },
              getFetchMore: (latestPage) => index++,
            );
            if (!context.hasMorePages) {
              print('No More!');
            }
            if (context.snapshot.hasData) {
              print(context.snapshot.data);
              if (!passed) {
                context.fetchMore();
                passed = true;
              }
            }
            return Container();
          },
        ),
      ),
      Duration(seconds: 5),
    );

    expect(passed, true);
  });
}

==> flutter_query-0.0.8.tar.gz: test/use_query_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:flutter_query/flutter_query.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  testWidgets('useQuery', (tester) async {
    var passed = false;

    await tester.pumpFrames(
      QueryCacheProvider(
        child: HookBuilder(
          builder: (context) {
            final snapshot = useQuery(
              'data',
              () => Future.value('Hello world!'),
            );
            if (snapshot?.hasData ?? false) {
              passed = true;
            }
            return Container();
          },
        ),
      ),
      Duration(seconds: 5),
    );

    expect(passed, true);
  });

  testWidgets('useInfiniteQuery', (tester) async {
    var passed = false;
    var index = 0;

    await tester.pumpFrames(
      QueryCacheProvider(
        child: HookBuilder(
          builder: (context) {
            final context = useInfiniteQuery(
              'data',
              (page) {
                print(page.toString());
                return Future.value(page > 0 ? [] : ['Test', 'Test', 'Test']);
              },
              getFetchMore: (latestPage) => index++,
            );
            if (!context.hasMorePages) {
              print('No More!');
            }
            if (context.snapshot.hasData) {
              print(context.snapshot.data);
              if (!passed) {
                context.fetchMore();
                passed = true;
              }
            }
            return Container();
          },
        ),
      ),
      Duration(seconds: 5),
    );

    expect(passed, true);
  });
}
